@@ -295,11 +295,15 @@ void Nepomuk::StrigiIndexWriter::startAnalysis( const AnalysisResult* idx )
     FileMetaData* data = new FileMetaData( idx, d->resourceUri );
 
     // remove previously indexed data
-    if( !data->resourceUri.isEmpty() ) {
-        Nepomuk::clearIndexedData(data->resourceUri)->exec();
-    }
-    else {
-        Nepomuk::clearIndexedData(data->fileUrl)->exec();
+    // but only for files. We cannot remove folders since that would also remove the
+    // nie:isPartOf links from the files.
+    if(!data->fileInfo.isDir()) {
+        if( !data->resourceUri.isEmpty() ) {
+            Nepomuk::clearIndexedData(data->resourceUri)->exec();
+        }
+        else {
+            Nepomuk::clearIndexedData(data->fileUrl)->exec();
+        }
     }
 
     // remember the file data
@@ -314,6 +318,12 @@ void Nepomuk::StrigiIndexWriter::addText( const AnalysisResult* idx, const char*
     }
 
     FileMetaData* md = fileDataForResult( idx );
+
+    // make sure text fragments are separated
+    if(md->content.size() > 0)
+        md->content.append( " " );
+
+    // append the new fragment
     md->content.append( text, length );
 }
 
@@ -417,9 +427,9 @@ void Nepomuk::StrigiIndexWriter::addTriplet( const std::string& s,
     FileMetaData* md = fileDataForResult( d->currentResultStack.top() );
 
     // convert the std strings to Qt values
-    const QString subResId(QLatin1String(s.c_str()));
+    const QString subResId(QString::fromUtf8(s.c_str()));
     const QUrl property(QString::fromUtf8(p.c_str()));
-    const QString value(QString::fromUtf8( o.c_str()));
+    const QString value(QString::fromUtf8(o.c_str()));
 
     // the subject might be the indexed file itself
     if(KUrl(subResId) == md->fileUrl) {
@@ -514,7 +524,7 @@ void Nepomuk::StrigiIndexWriter::finishAnalysis( const AnalysisResult* idx )
     additionalMetadata.insert( RDF::type(), NRL::DiscardableInstanceBase() );
 
     // we do not have an event loop - thus, we need to delete the job ourselves
-    QScopedPointer<KJob> job( Nepomuk::storeResources( graph, Nepomuk::IdentifyNew, Nepomuk::LazyCardinalities, additionalMetadata ) );
+    QScopedPointer<KJob> job( Nepomuk::storeResources( graph, Nepomuk::IdentifyNew, Nepomuk::LazyCardinalities|Nepomuk::OverwriteProperties, additionalMetadata ) );
     job->setAutoDelete(false);
     job->exec();
     if( job->error() ) {
